@@ -529,37 +529,6 @@ int g_do_run_cmds(char *cmd, int restart)
 	return r;
 }
 
-int show_intro(void)
-{
-	GtkWidget *dialog, *label; int r = 0;
-	gint result; 
-
-	dialog = gtk_dialog_new_with_buttons(_("Execution:"),
-					     GTK_WINDOW(main_wnd),
-					     (GtkDialogFlags)
-					     (GTK_DIALOG_MODAL |
-					      GTK_DIALOG_DESTROY_WITH_PARENT),
-					     GTK_STOCK_OK,
-					     GTK_RESPONSE_YES,
-					     NULL);
-	gtk_dialog_set_default_response(GTK_DIALOG(dialog),
-					GTK_RESPONSE_CANCEL);
-
-	label = gtk_label_new(_("Note: Commands can be executed from within the configuratior now\n"
-		     "by double-clicking on \"Execute ...\" configuration entries.\n"
-		     "It is not neccessary any more to exit the GUI for \ni.e. \"install/upgrade\" and \"build\".\n"
-				"The LINUX and BUILDROOT configuration trees are accessible\n"
-		     "as subtrees in this configurator.\n"));
-	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), label);
-	gtk_widget_show(label);
-
-	result = gtk_dialog_run(GTK_DIALOG(dialog));
-
-	gtk_widget_destroy(dialog);
-	return r;
-}
-
-
 void on_window1_destroy(GtkObject * object, gpointer user_data)
 {
 	gtk_main_quit();
@@ -1643,8 +1612,7 @@ int main(int ac, char *av[])
 		display_tree(&rootmenu);
 		break;
 	}
-	show_intro();
-	
+
 	f_do_run_cmds = g_do_run_cmds;
 	gtk_main();
 
