@@ -817,88 +817,6 @@ int m_do_run_cmds(char *cmd, int restart)
 	return res == 0 ? 1 : 0;
 }
 
-int show_intro(void)
-{
-	int res;
-	const char *title = 0; const char *prompt = 0; int height = 20; int width = 80;
-	prompt = "Note: Commands can be executed from within the configuratior now\n"
-		"by double-clicking on \"Execute ...\" configuration entries.\n"
-		"It is not neccessary any more to exit the GUI for \ni.e. \"install/upgrade\" and \"build\".\n"
-		"The LINUX and BUILDROOT configuration trees are accessible\n"
-		"as subtrees in this configurator.\n";
-	
-	{
-		int i, x, y, key = 0, button = 0;
-		WINDOW *dialog;
-		
-	do_resize:
-		if (getmaxy(stdscr) < (height + 4))
-			return -ERRDISPLAYTOOSMALL;
-		if (getmaxx(stdscr) < (width + 4))
-			return -ERRDISPLAYTOOSMALL;
-		
-		/* center dialog box on screen */
-		x = (COLS - width) / 2;
-		y = (LINES - height) / 2;
-		
-		draw_shadow(stdscr, y, x, height, width);
-		
-		dialog = newwin(height, width, y, x);
-		keypad(dialog, TRUE);
-		
-		draw_box(dialog, 0, 0, height, width,
-			 dlg.dialog.atr, dlg.border.atr);
-		wattrset(dialog, dlg.border.atr);
-		mvwaddch(dialog, height - 3, 0, ACS_LTEE);
-		for (i = 0; i < width - 2; i++)
-			waddch(dialog, ACS_HLINE);
-		wattrset(dialog, dlg.dialog.atr);
-		waddch(dialog, ACS_RTEE);
-		
-		print_title(dialog, title, width);
-		
-		wattrset(dialog, dlg.dialog.atr);
-		print_autowrap(dialog, prompt, width - 2, 1, 3);
-
-		{
-			int x = width / 2;
-			int y = height - 2;
-			print_button(dialog, gettext(" Ok "), y, x, 1);
-		}
-		
-		while (key != KEY_ESC) {
-			key = wgetch(dialog);
-			switch (key) {
-			case 'Y':
-			case 'y':
-				delwin(dialog);
-				return 0;
-			case 'N':
-			case 'n':
-				delwin(dialog);
-				return 1;
-				
-			case ' ':
-			case '\n':
-				delwin(dialog);
-				return button;
-			case KEY_ESC:
-				key = on_key_esc(dialog);
-				break;
-			case KEY_RESIZE:
-				delwin(dialog);
-				on_key_resize();
-				goto do_resize;
-			}
-		}
-		
-		delwin(dialog);
-		return key;		/* ESC pressed */
-	}
-	return 0;
-}
-
-
 void m_restart_app(void) 
 {
 	longjmp(buf,1);
@@ -937,8 +855,6 @@ int main(int ac, char **av)
 	
 	set_config_filename(conf_get_configname());
 
-	show_intro();
-	
 	if ( ! setjmp(buf) ) {
 		do {
 			conf(&rootmenu);
