@@ -1770,21 +1770,6 @@ int q_do_run_cmds(char *cmd, int restart)
 	return 0;
 }
 
-
-int show_intro(void)
-{
-	char b[1024];
-	QMessageBox mb;
-	mb.setText(_("Note: Commands can be executed from within the configuratior now\n"
-		     "by double-clicking on \"Execute ...\" configuration entries.\n"
-		     "It is not neccessary any more to exit the GUI for \ni.e. \"install/upgrade\" and \"build\".\n"
-		     "The LINUX and BUILDROOT configuration trees are accessible\n"
-		     "as subtrees in this configurator."));
-	mb.exec();
-	return 0;
-}
-
-
 void q_restart_app(void) 
 {
 	configApp->exit(get_restart());
@@ -1833,8 +1818,6 @@ int main(int ac, char** av)
 	configApp->connect(configApp, SIGNAL(lastWindowClosed()), SLOT(quit()));
 	configApp->connect(configApp, SIGNAL(aboutToQuit()), v, SLOT(saveSettings()));
 	v->show();
-	show_intro();
-	
 	configApp->exec();
 
 	configSettings->endGroup();
